@@ -54,14 +54,4 @@ class StaticUtils:
    
    @staticmethod
    def round(value):
-      try:
-         return [StaticUtils.round(val) for val in value]
-      
-      except TypeError:
-         try:
-            value = value.item() # numpy case.
-         
-         except AttributeError:
-            pass
-         
-         return int(Decimal(value).to_integral_value(ROUND_HALF_UP))
+      return [StaticUtils.round(val) for val in value] if StaticUtils.isIterable(value) else int(Decimal(value).to_integral_value(ROUND_HALF_UP))
